Copied from:  
https://github.com/squidfunk/mkdocs-material/tree/master/src/assets/stylesheets  
https://github.com/mrmlnc/material-color/blob/master/material-color.scss  
https://github.com/mrmlnc/material-shadows/blob/master/material-shadows.scss

These are covered by the following licenses, respectively:
LICENSE-mkdocs-material
LICENSE-material-color
LICENSE-material-shadows
